<?php
/**
 * Plugin Name: Mertes & Leven KI Content
 * Plugin URI: https://www.mertes-leven.de/api/plugin
 * Description: Ein Plugin, das Inhalte von einer spezialisierten API abruft und als WordPress-Beiträge speichert.
 * Version: 1.0.0.1
 * Author: Mertes & Leven GbR
 * Author URI: https://www.mertes-leven.de/unternehmen/
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: ml-ki-content
 */


defined('ABSPATH') or die('Direkter Zugriff ist nicht erlaubt.');

function ml_ki_content_menu() {
    add_menu_page(
        'Mertes & Leven KI Content',
        'ML-KI Content',
        'manage_options',
        'ml-ki-content-settings',
        'ml_ki_content_settings_page',
        'dashicons-media-text',
        100
    );
}
add_action('admin_menu', 'ml_ki_content_menu');

function ml_ki_content_settings_page() {
    echo '<h1>Mertes & Leven KI Content</h1>';
    ?>
    <div class="wrap">
        <form method="post" action="options.php">
            <?php
            settings_fields('ml_ki_content_options_group');
            do_settings_sections('ml-ki-content-settings');
            ?>
            <div style="border: 1px solid grey; padding: 10px; margin-bottom: 20px; max-width: 500px;">
                <p>Information: Das Plugin holt bei jedem Abruf nur einen Artikel aus Ihrem <a target="_blank" href="https://www.mertes-leven.de/api/useredit.php">Account</a> und zwar den jeweils aktuellsten. In Ihrem Account sind eventuell noch weitere Artikel, die später übertragen werden. Diese können Sie aber auch manuell veröffentlichen.</p>
            </div>
            <?php
            submit_button();
            ?>
        </form>
    </div>
    <?php
    
    if (isset($_POST['fetch_content'])) {
        $last_clicked = get_option('ml_ki_content_last_clicked', 0);
        $current_time = current_time('timestamp');

        if ($current_time - $last_clicked > 3600) {
            ml_ki_content_create_posts();
            echo '<div class="updated"><p>Inhalte erfolgreich abgerufen!</p></div>';
            update_option('ml_ki_content_last_clicked', $current_time);
        } else {
            echo '<div class="error"><p>Bitte warten Sie noch etwas, bevor Sie erneut Inhalte abrufen.</p></div>';
        }
    }
    
    $current_time = current_time('timestamp');
    $last_clicked = get_option('ml_ki_content_last_clicked', 0);

    if ($current_time - $last_clicked > 3600) {
        ?>
        <form method="post">
            <input type="submit" name="fetch_content" value="Inhalte jetzt abrufen (Vorerst 1x/Std. möglich)" class="button button-primary">
        </form>
        <?php
    } else {
        $minutes_remaining = ceil((3600 - ($current_time - $last_clicked)) / 60);
        echo '<p>Sie können in ' . $minutes_remaining . ' Minuten erneut Inhalte abrufen.</p>';
    }
}
add_action('admin_init', 'ml_ki_content_register_settings');



function ml_ki_content_register_settings() {
    register_setting('ml_ki_content_options_group', 'ml_ki_content_options');

    add_settings_section(
        'ml_ki_content_api_section',
        'API Einstellungen',
        'ml_ki_content_api_section_callback',
        'ml-ki-content-settings'
    );

    add_settings_field(
        'api_key',
        'API Schlüssel',
        'ml_ki_content_api_key_callback',
        'ml-ki-content-settings',
        'ml_ki_content_api_section'
    );

	// Veröffentlichungsoptionen
	add_settings_field(
	    'publish_option',
	    'Veröffentlichungsoption',
	    'ml_ki_content_publish_option_callback',
	    'ml-ki-content-settings',
	    'ml_ki_content_api_section'
	);
	
	// E-Mail-Benachrichtigungen
	add_settings_field(
	    'email_notifications',
	    'E-Mail Benachrichtigungen',
	    'ml_ki_content_email_notifications_callback',
	    'ml-ki-content-settings',
	    'ml_ki_content_api_section'
	);
	
	// Planungsoptionen
	add_settings_field(
	    'schedule_option',
	    'Artikel-Interval',
	    'ml_ki_content_schedule_option_callback',
	    'ml-ki-content-settings',
	    'ml_ki_content_api_section'
	);

}

function ml_ki_content_api_section_callback() {
    echo '<p>Diese Anwendung liefert automatisiert WordPress-Beiträge zu ausgewählten Themen.<br> <b>Ein API-Key wird zum Betrieb benötigt.</b> <br>Für die Themenauswahl und den API-Key können Sie sich <a target="_blank" href="https://www.mertes-leven.de/api/regi.php">hier Registrieren</a>.<br> Wenn Sie schon einen Account haben, können Sie <a target="_blank" href="https://www.mertes-leven.de/api/useredit.php"> hier Einstellungen vornehmen</a>.</p>';
}

function ml_ki_content_api_key_callback() {
    $options = get_option('ml_ki_content_options');
    echo '<input type="password" id="api_key" name="ml_ki_content_options[api_key]" value="' . esc_attr($options['api_key'] ?? '') . '">';
}


function ml_ki_content_publish_option_callback() {
    $options = get_option('ml_ki_content_options');
    $value = $options['publish_option'] ?? 'draft';
    echo '<select id="publish_option" name="ml_ki_content_options[publish_option]">';
    echo '<option value="publish" ' . selected($value, 'publish', false) . '>Beiträge ungesehen veröffentlichen</option>';
    echo '<option value="draft" ' . selected($value, 'draft', false) . '>Beiträge als Entwurf speichern</option>';
    echo '</select>';
}

function ml_ki_content_email_notifications_callback() {
    $options = get_option('ml_ki_content_options');
    $checked = isset($options['email_notifications']) ? 'checked' : '';
    echo '<input type="checkbox" id="email_notifications" name="ml_ki_content_options[email_notifications]" value="1" ' . $checked . '> Benachrichtigung bei neuem Artikel!';
}

function ml_ki_content_schedule_option_callback() {
    $options = get_option('ml_ki_content_options');
    $value = $options['schedule_option'] ?? 'weekly';
    echo '<select id="schedule_option" name="ml_ki_content_options[schedule_option]">';
    echo '<option value="daily" ' . selected($value, 'daily', false) . '>Täglich</option>';
    echo '<option value="weekly" ' . selected($value, 'weekly', false) . '>Wöchentlich (empfohlen)</option>';
    echo '<option value="monthly" ' . selected($value, 'monthly', false) . '>Monatlich</option>';
    echo '</select>';
}

function ml_ki_content_fetch_api() {
    $options = get_option('ml_ki_content_options');
    $api_key = $options['api_key'] ?? '';

    if (empty($api_key)) {
        return false; 
    }

    $url = "https://www.mertes-leven.de/api/v1/articles/?api_key=" . $api_key;
    $response = wp_remote_get($url);

    if (is_wp_error($response)) {
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return $data;
}

function ml_ki_content_create_posts() {
    $data = ml_ki_content_fetch_api();

    if (!$data || !isset($data['status']) || $data['status'] !== 'success' || !isset($data['article'])) {
        // Fehlgeschlagene API-Anfrage, ungültige Daten oder keine Artikel gefunden
        return;
    }

    $article = $data['article'];
    $options = get_option('ml_ki_content_options');
    $post_status = $options['publish_option'] ?? 'draft';

   
    if (isset($article['title'], $article['content'])) {
        $post_data = array(
            'post_title'    => wp_strip_all_tags($article['title']),
            'post_content'  => $article['content'],
            'post_status'   => $post_status,
        );

        $post_id = wp_insert_post($post_data);

        if ($post_id) {
            
            // Zusätzliche Metadaten oder Taxonomien

            if (isset($options['email_notifications']) && $options['email_notifications']) {
                ml_ki_content_send_email_notification($post_id);
            }
        }
    }
}

function ml_ki_content_send_email_notification($post_id) {
    $post = get_post($post_id);
    $title = $post->post_title;
    $email = get_option('admin_email'); 
    $post_status = $post->post_status;

    $subject = 'Neuer Artikel vom Mertes & Leven KI Content-Tool verfügbar';

    if ($post_status == 'publish') {
        $link = get_permalink($post_id);
        $message = "Guten Tag!\n\nFür Sie wurde ein neuer Artikel vom Mertes & Leven KI Content-Tool veröffentlicht. Schauen Sie gleich nach:\n\n" . $link . "\n\nIhr Mertes & Leven KI Team";
    } else {
        $link = admin_url('post.php?post=' . $post_id . '&action=edit');
        $message = "Guten Tag!\n\nFür Sie liegt ein neuer Entwurf vom Mertes & Leven KI Content-Tool vor. Schauen Sie gleich in WordPress nach:\n\n" . $link . "\n\nIhr Mertes & Leven KI Team";
    }

    wp_mail($email, $subject, $message); 
}





// Planungsfunktion
function ml_ki_content_schedule_cron() {
    $options = get_option('ml_ki_content_options');
    $schedule_option = $options['schedule_option'] ?? 'daily';

    
    if (wp_next_scheduled('ml_ki_content_cron_hook')) {
        wp_clear_scheduled_hook('ml_ki_content_cron_hook');
    }

    
    wp_schedule_event(time(), $schedule_option, 'ml_ki_content_cron_hook');
}


function ml_ki_content_activate() {
    ml_ki_content_schedule_cron(); 
}
register_activation_hook(__FILE__, 'ml_ki_content_activate');


function ml_ki_content_deactivate() {
    wp_clear_scheduled_hook('ml_ki_content_cron_hook'); 
}
register_deactivation_hook(__FILE__, 'ml_ki_content_deactivate');


add_action('ml_ki_content_cron_hook', 'ml_ki_content_create_posts');

function ml_ki_content_add_cron_intervals($schedules) {
    $schedules['weekly'] = array(
        'interval' => 604800, // 1 Woche in Sekunden
        'display' => __('Wöchentlich')
    );
    $schedules['monthly'] = array(
        'interval' => 2592000, // 1 Monat in Sekunden
        'display' => __('Monatlich')
    );
    return $schedules;
}
add_filter('cron_schedules', 'ml_ki_content_add_cron_intervals');

function ml_ki_content_add_settings_link($links) {
    $settings_link = '<a href="admin.php?page=ml-ki-content-settings">' . __('Einstellungen') . '</a>';
    array_push($links, $settings_link);
    return $links;
}

$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 'ml_ki_content_add_settings_link');


